@@ -1,6 +1,6 @@
 /* tutoterm.h -- header file for app functions
  *
- * Copyright © 2017 Félicien Pillot <felicien@gnu.org>
+ * Copyright © 2017,2019 Félicien Pillot <felicien@gnu.org>
  * This file is part of TutoTerm.
  * 
  * TutoTerm is free software: you can redistribute it and/or modify
@@ -22,12 +22,21 @@
 
 #include <gtk/gtk.h>
 
-void        activate            (GtkApplication* app, gpointer user_data);
-GtkWidget*  get_ttlabel         (GtkWidget* widget);
-GtkWidget*  get_ttvtextbox      (GtkWidget* widget);
-gboolean    key_event           (GtkWidget* widget, GdkEventKey* event,
-				 GtkListStore* ttListStore);
+void	   activate               (GtkApplication*    app,
+				   gpointer	      user_data);
+GtkWidget* get_ttlabel            (GtkWidget*         widget);
+GtkWidget* get_ttvtextbox         (GtkWidget*         widget);
+gboolean   key_event              (GtkWidget*         widget,
+				   GdkEventKey*	      event,
+				   GtkListStore*      ttListStore);
+void       preferences_activated  (GSimpleAction     *action,
+				   GVariant	     *parameter,
+				   gpointer	      user_data);
+void       quit_activated         (GSimpleAction     *action,
+				   GVariant	     *parameter,
+				   gpointer	      user_data);
 
 GtkWidget *ttExample, *ttLabelExample;
+//const char *accels[] = {"<Contol>Q", NULL};
 
 #endif /* __TUTOTERM_H */
