@@ -1,6 +1,6 @@
 /* main.c -- main file of TutoTerm
  *
- * Copyright © 2017 Félicien Pillot <felicien@gnu.org>
+ * Copyright © 2017,2019 Félicien Pillot <felicien@gnu.org>
  * This file is part of TutoTerm.
  * 
  * TutoTerm is free software: you can redistribute it and/or modify
@@ -25,8 +25,7 @@
 #include "../include/tutoterm.h"
 
 int
-main (int    argc,
-      char **argv)
+main (int argc, char **argv)
 {
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
